@@ -74,13 +74,19 @@ class HTTPChannel(logging_dispatcher, object):
         asyncore.dispatcher.__init__(self, sock, map=map)
 
     def writable(self):
-        return bool(self.outbuf)
+        # if there's data in the out buffer or we've been instructed to close
+        # the channel (possibly by our server maintenance logic), run
+        # handle_write
+        return bool(self.outbuf) or self.will_close
 
     def handle_write(self):
-        # Precondition: there's data in the out buffer to be sent
+        # Precondition: there's data in the out buffer to be sent, or
+        # there's a pending will_close request
         if not self.connected:
+            # we dont want to close the channel twice
             return
 
+        # try to flush any pending output
         if not self.requests:
             # 1. There are no running tasks, so we don't need to try to lock
             #    the outbuf before sending
@@ -116,6 +122,7 @@ class HTTPChannel(logging_dispatcher, object):
                 if self.adj.log_socket_errors:
                     self.logger.exception('Socket error')
                 self.will_close = True
+
         if self.will_close:
             self.handle_close()
 
@@ -197,16 +204,20 @@ class HTTPChannel(logging_dispatcher, object):
         # Send as much data as possible to our client
         outbuf = self.outbuf
         outbuflen = len(outbuf)
+        sent = 0
         while outbuflen > 0:
             chunk = outbuf.get(self.adj.send_bytes)
             num_sent = self.send(chunk)
             if num_sent:
                 outbuf.skip(num_sent, True)
                 outbuflen -= num_sent
+                sent += num_sent
             else:
-                return False
-        self.last_activity = time.time()
-        return True
+                break
+        if sent:
+            self.last_activity = time.time()
+            return True
+        return False
 
     def handle_close(self):
         self.connected = False
@@ -241,11 +252,15 @@ class HTTPChannel(logging_dispatcher, object):
             # block here waiting for it because we're in a thread
             with self.outbuf.lock:
                 self.outbuf.append(data)
+            # XXX We might eventually need to pull the trigger here (to
+            # instruct select to stop blocking), but it slows things down so
+            # much that I'll hold off for now; "server push" on otherwise
+            # unbusy systems may suffer.
             return len(data)
         return 0
 
     def service(self):
-        """Execute a pending task"""
+        """Execute all pending requests """
         with self.task_lock:
             while self.requests:
                 request = self.requests[0]
